# -*- coding: utf-8 -*-
"""Watchfiles main file."""
import logging
import os
import subprocess
import sys
import time
from datetime import datetime

import click
from blessings import Terminal

# Global Variables
t = Terminal()
logging.basicConfig(level=logging.INFO)
log = logging.getLogger(__name__)


def execute_command(command):
    """Execute a command, log any errors if they arise."""
    proc_command = command.split()
    try:
        proc = subprocess.Popen(
            proc_command,
            stdout=subprocess.PIPE)
    except FileNotFoundError as e:
        log.exception('Error trying to execute "{}"'.format(command))
        sys.exit()
    out, err = proc.communicate()
    if err:
        log.critical('Error trying to execute "{}": {}'.format(command, err))
        sys.exit()
    else:
        click.echo(out)


@click.command()
@click.argument('files', type=click.Path(exists=True), nargs=-1)
@click.argument('command', nargs=1)
def main(files, command):
    """Execute the watchfiles command."""
    t.clear()
    last_change_detected = datetime.now()
    click.echo(t.bold('Watching for Changes...'))
    while True:
        for file in files:
            try:
                timestamp = os.path.getmtime(file)
            except OSError:
                click.echo('Error getting timestamp for file: {}'.format(file))
                sys.exit()
            last_update = datetime.fromtimestamp(timestamp)
            if last_change_detected < last_update:
                last_change_detected = datetime.now()
                click.echo('{} {}'.format(t.bold('Executing'), command))
                execute_command(command)
        time.sleep(0.5)


if __name__ == '__main__':
    main()
